# R Script File for Section 5: Clustering in R

WHO = read.csv("WHO.csv")
WHOCluster = WHO[c("Population", "Under15", "Over60", "LifeExpectancy")]

# Normalization
install.packages("caret")
library(caret)
preproc = preProcess(WHOCluster)
WHOClusterNorm = predict(preproc, WHOCluster)

# Hierarchical Clustering
distances = dist(WHOClusterNorm, method="euclidean")
HierClustering = hclust(distances, method="ward")
plot(HierClustering)

clusterGroups = cutree(HierClustering, k = 3)
table(clusterGroups)
tapply(WHOCluster$Population, clusterGroups, mean)
tapply(WHOCluster$Under15, clusterGroups, mean)
tapply(WHOCluster$Over60, clusterGroups, mean)
tapply(WHOCluster$LifeExpectancy, clusterGroups, mean)

# K-means clustering

set.seed(100)
KmeansClustering = kmeans(WHOClusterNorm, centers = 3)
table(KmeansClustering$cluster)