# R Script File for Section 3: Logistic Regression in R

Quality = read.csv("Quality.csv")

# Creating Training and Testing Sets
install.packages("caTools")
library(caTools)

set.seed(88)
spl = sample.split(Quality$PoorCare, SplitRatio = 0.75)
QualityTrain = subset(Quality, spl==TRUE)
QualityTest = subset(Quality, spl==FALSE)

# Building a Logistic Regression Model
QualityModel = glm(PoorCare ~ ERVisits + OfficeVisits + Narcotics + ProviderCount + NumberClaims + StartedOnCombination, data = QualityTrain, family=binomial)
summary(QualityModel)

# Evaluating the Model
PredictTrain = predict(QualityModel, type="response")
table(QualityTrain$PoorCare, PredictTrain > 0.5)

install.packages("ROCR")
library(ROCR)

ROCRpred = prediction(PredictTrain, QualityTrain$PoorCare)
ROCCurve = performance(ROCRpred, "tpr", "fpr")
plot(ROCCurve)
plot(ROCCurve, colorize=TRUE, print.cutoffs.at=seq(0,1,0.1), text.adj=c(-0.2,0.7))
as.numeric(performance(ROCRpred, "auc")@y.values)
PredictTest = predict(QualityModel, type="response", newdata=QualityTest)
table(QualityTest$PoorCare, PredictTest > 0.5)