# R Script File for Section 6: Visualization

WHO = read.csv("WHO.csv")

install.packages("ggplot2")
library(ggplot2)

ggplot(WHO, aes(x = GNI, y = FertilityRate)) + geom_point()

ggplot(WHO, aes(x = GNI, y = FertilityRate)) + geom_point(color="blue", size = 3, shape = 17) + ggtitle("Fertility Rate vs. Gross National Income") + xlab("Gross National Income") + ylab("Fertility Rate")

ggplot(WHO, aes(x = GNI, y = FertilityRate, color=Region)) + geom_point()

# Line Plots

Crime = read.csv("Crime.csv")

Crime$Date = strptime(Crime$Date, format = "%m/%d/%y %H:%M")
Crime$Weekdays = weekdays(Crime$Date)
WeekdayCounts = as.data.frame(table(Crime$Weekdays))

ggplot(WeekdayCounts, aes(x=Var1, y=Freq)) + geom_line(aes(group=1))

WeekdayCounts$Var1 = factor(WeekdayCounts$Var1, ordered=TRUE, levels=c("Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday"))
ggplot(WeekdayCounts, aes(x=Var1, y=Freq)) + geom_line(aes(group=1))

# Heat Maps

Crime$Hour = Crime$Date$hour
WeekdayHourCounts = as.data.frame(table(Crime$Weekdays, Crime$Hour))

WeekdayHourCounts$Var1 = factor(WeekdayHourCounts$Var1, ordered=TRUE, levels=c("Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday"))
WeekdayHourCounts$Var2 = as.numeric(as.character(WeekdayHourCounts$Var2))

ggplot(WeekdayHourCounts, aes(x = Var2, y = Var1)) + geom_tile(aes(fill = Freq)) + xlab("Hour of the Day") + ylab("")

ggplot(WeekdayHourCounts, aes(x = Var2, y = Var1)) + geom_tile(aes(fill = Freq)) + xlab("Hour of the Day") + ylab("") + scale_fill_gradient(low="white", high="red")

install.packages("maps")
library(maps)
install.packages("ggmap")
library(ggmap)

chicago = get_map(location = "chicago", zoom = 11)
ggmap(chicago)

LatLongCounts = as.data.frame(table(round(Crime$Longitude, 2), round(Crime$Latitude, 2)))

LatLongCounts$Var1 = as.numeric(as.character(LatLongCounts$Var1))
LatLongCounts$Var2 = as.numeric(as.character(LatLongCounts$Var2))

ggmap(chicago) + geom_tile(data=LatLongCounts, aes(x = Var1, y = Var2, alpha = Freq), fill = "red")

# United States Maps

Unemployment = read.csv("Unemployment.csv")

StatesMap = map_data("state")

ggplot(StatesMap, aes(x = long, y = lat, group = group)) + geom_polygon(fill = "white", color="black")

UnemploymentMap = merge(StatesMap, Unemployment, by.x = "region", by.y = "State")

ggplot(UnemploymentMap, aes(x = long, y = lat, group = group, fill = Rate2009)) + geom_polygon(color="black")